==> peekabot-0.6.0.tar.bz2: peekabot-0.6.0/src/actions/SetHingeAxis.cc <==
/*
 * Copyright Staffan Gimåker 2009.
 *
 * ---
 *
 * Distributed under the Boost Software License, Version 1.0.
 * (See accompanying file LICENSE_1_0.txt or copy at
 * http://www.boost.org/LICENSE_1_0.txt)
 */

#include <boost/math/fpclassify.hpp>

#include "SetHingeAxis.hh"

#ifdef __PEEKABOT_SERVER
#  include "../ServerExecutionContext.hh"
#  include "../Hinge.hh"
#endif


using namespace peekabot;


SetHingeAxis::SetHingeAxis(
    ObjectID target,
    float x, float y, float z,
    CoordinateSystem coord_sys)
    : m_target(target),
      m_x(x), m_y(y), m_z(z),
      m_coord_sys(coord_sys)
{
}


SetHingeAxis::SetHingeAxis() throw()
{
}


SetHingeAxis::SetHingeAxis(const SetHingeAxis &other) throw()
    : m_target(other.m_target),
      m_x(other.m_x), m_y(other.m_y), m_z(other.m_z),
      m_coord_sys(other.m_coord_sys)
{
}


SetHingeAxis::~SetHingeAxis() throw()
{
}


Action *SetHingeAxis::clone() const
{
    return new SetHingeAxis(*this);
}


void SetHingeAxis::execute(
    ServerExecutionContext *context)
    const throw(std::exception)
{
#ifdef __PEEKABOT_SERVER
    Hinge *ptr = dynamic_cast<Hinge *>(context->get_object(m_target));

    if( !ptr )
        throw std::runtime_error(
            "Failed to set hinge axis, target object not found or "
            "of non-hinge type");

    // Check for infinity and NaN
    if( !boost::math::isfinite(m_x) ||
        !boost::math::isfinite(m_y) ||
        !boost::math::isfinite(m_z) )
        throw std::logic_error(
                "Failed to set hinge axis: axis "
                "cannot contain infinity or NaN");


    ptr->set_axis(Vector3f(m_x, m_y, m_z), m_coord_sys);
#endif
}


void SetHingeAxis::save(SerializationInterface &ar) const
{
    ar << m_target << m_x << m_y << m_z << m_coord_sys;
}

void SetHingeAxis::load(DeserializationInterface &ar)
{
    ar >> m_target >> m_x >> m_y >> m_z >> m_coord_sys;
}

==> peekabot-0.8.4.tar.bz2: peekabot-0.8.4/src/actions/SetHingeAxis.cc <==
/*
 * Copyright Staffan Gimåker 2009.
 *
 * ---
 *
 * Distributed under the Boost Software License, Version 1.0.
 * (See accompanying file LICENSE_1_0.txt or copy at
 * http://www.boost.org/LICENSE_1_0.txt)
 */

#include "SetHingeAxis.hh"

#ifdef __PEEKABOT_SERVER
#  include "../ServerExecutionContext.hh"
#  include "../Hinge.hh"
#endif

#include <boost/math/fpclassify.hpp>
#include <Eigen/Core>
#include <stdexcept>


using namespace peekabot;


SetHingeAxis::SetHingeAxis(
    ObjectID target,
    float x, float y, float z,
    CoordinateSystem coord_sys)
    : m_target(target),
      m_x(x), m_y(y), m_z(z),
      m_coord_sys(coord_sys)
{
}


SetHingeAxis::SetHingeAxis() throw()
{
}


SetHingeAxis::SetHingeAxis(const SetHingeAxis &other) throw()
    : m_target(other.m_target),
      m_x(other.m_x), m_y(other.m_y), m_z(other.m_z),
      m_coord_sys(other.m_coord_sys)
{
}


SetHingeAxis::~SetHingeAxis() throw()
{
}


Action *SetHingeAxis::clone() const
{
    return new SetHingeAxis(*this);
}


void SetHingeAxis::execute(ServerExecutionContext *context) const
{
#ifdef __PEEKABOT_SERVER
    Hinge *ptr = dynamic_cast<Hinge *>(context->get_object(m_target));

    if( !ptr )
        throw std::runtime_error(
            "Failed to set hinge axis, target object not found or "
            "of non-hinge type");

    // Check for infinity and NaN
    if( !boost::math::isfinite(m_x) ||
        !boost::math::isfinite(m_y) ||
        !boost::math::isfinite(m_z) )
        throw std::logic_error(
                "Failed to set hinge axis: axis "
                "cannot contain infinity or NaN");


    ptr->set_axis(Eigen::Vector3f(m_x, m_y, m_z), m_coord_sys);
#endif
}


void SetHingeAxis::save(SerializationInterface &ar) const
{
    ar << m_target << m_x << m_y << m_z << m_coord_sys;
}

void SetHingeAxis::load(DeserializationInterface &ar)
{
    ar >> m_target >> m_x >> m_y >> m_z >> m_coord_sys;
}
